=======
Credits
=======

Development Lead
----------------

* Daniel Greenfeld <pydanny@gmail.com>
* Buddy Lindsley
* Yasmine Charif (@dollydagr)
* Audrey Roy
* Mahdi Yusuf (@myusuf3)
* Alexander Kavanaugh (@kavdev)

Contributors
------------

* Luis Montiel <luismmontielg@gmail.com>
* Kulbir Singh (@kulbir)
* Dustin Farris (@dustinfarris)
* Liwen S (@sunliwen)
* centrove
* Chris Halpert (@cphalpert)
* Thomas Parslow (@almost)
* Leonid Shvechikov (@shvechikov)
* sromero84
* Peter Baumgartner (@ipmb)
* Vikas (@vikasgulati)
* Colton Allen (@cmanallen)
* Filip Wasilewski (@nigma)
* Martin Hill (@martinhill)
* Michael Thornhill <michael.thornhill@gmail.com>
* Tobias Lorenz (@Tyrdall)
* Ben Whalley
* nanvel
* jRobb (@jamesbrobb)
